QUOTES = ["Why, dear boy, we don't send wizards to Azkaban just for blowing up their aunts.",
 'Do I look stupid? snarled Uncle Vernon, a bit of fried egg dangling from his bushy mustache.',
 "Percy wouldn't notice a joke if it danced naked in front of him wearing one of Dobby's hats.",
 "Honestly, if you were any slower, you'd be going backward.",
 "Gotta bone ter pick with yeh. I've heard you've bin givin' out signed photos. How come I haven't got one?",
 "Your sons flew that car to Harry's house and back last night! ...  What have you got to say about that, eh? Did you really... Did it go all right? I - I mean...  that - that was very wrong, boys - very wrong indeed.",
 "Ron's old Shooting Star was often outstripped by passing butterflies.",
 'We tried to shut Percy in a pyramid. But Mum spotted us.',
 'Lockhart cuffed Harry merrily on the shoulder. Just do what I did, Harry! What, drop my wand?',
 "Where is Wood? said Harry, suddenly realizing he wasn't there. Still in the showers, said Fred. We think he's trying to drown himself.",
 "I dreamed I was buying new shoes last night, said Ron. What d'ya think that's gonna mean? Probably that you're going to be eaten by a giant marshmallow or something, said Harry.",
 "And it's Gryffindor in possession again, as Johnson takes the Quaffle-Flint alongside her-poke him in the eye, Angelina-it was a joke, professor, it was a joke...",
 'I assure you that if you die, you need not hand it [homework] in.',
 "Don't talk to me. Why not? Because I want to fix that in my memory for ever. Draco Malfoy, the amazing bouncing ferret...",
 "Well, I certainly don't, said Percy sanctimoniously. I shudder to think what the state of my in-tray would be if I was away from work for five days. Yeah, someone might slip dragon dung in it again, eh, Perce? said Fred. That was a sample of fertilizer from Norway! said Percy, going very red in the face. It was nothing personal!' It was, Fred whispered to Harry as they got up from the table. We sent it.",
 'Anyone can speak Troll. All you have to do is point and grunt.',
 "I'm never wearing them, Ron was saying stubbornly. Never. Fine, snapped Mrs. Weasley. Go naked. And, Harry, make sure you get a picture of him. Goodness knows I could do with a laugh.",
 'Can I have a look at Uranus too, Lavender?',
 "Well, I can certainly see why we're trying to keep them alive. Who wouldn't want pets that can burn, sting, and bite all at once?",
 "My own brother, Aberforth, was prosecuted for practicing inappropriate charms on a goat. It was all over the papers, but did Aberforth hide? No, he did not! He held his head high and went about his business as usual! Of course, I'm not entirely sure he can read, so that may not have been bravery...",
 'Wild! I can make that old bloke down there pick his nose again...  and again...  and again...',
 "There you go, Harry! You weren't being thick after all; you were just showing moral fiber!",
 "You're a prefect? Oh Ronnie! That's everyone in the family! What are Fred and I? Next door neighbors?",
 'Yeah, Quirrell was a great teacher. There was just that minor drawback of him having Lord Voldemort sticking out of the back of his head!',
 'Listening to the news! Again? Well, it changes every day, you see, said Harry.',
 'Accio Brain!',
 "Don't put your wand there, boy! ...  Better wizards than you have lost buttocks, you know.",
 "This is night, Diddykins. That's what we call it when it goes all dark like this.",
 "Do you remember me telling you we are practicing non-verbal spells, Potter? Yes, said Harry stiffly. Yes, sir. There's no need to call me 'sir' Professor.",
 "You'd think people had better things to gossip about, said Ginny as she sat on the common room floor, leaning against Harry's legs and reading the Daily Prophet. Three Dementor attacks in a week, and all Romilda Vane does is ask me if it's true you've got a Hippogriff tattooed across your chest. Ron and Hermione both roared with laughter. Harry ignored them. What did you tell her? I told her it's a Hungarian Horntail, said Ginny, turning a page of the newspaper idly. Much more macho. Thanks, said Harry, grinning. And what did you tell her Ron's got? A Pygmy Puff, but I didn't say where.",
 "Why are you worrying about YOU-KNOW-WHO, when you should be worrying about YOU-NO-POO? The constipation sensation that's gripping the nation!",
 'Yes, it is easy to see that nearly six years of magical education have not been wasted on you, Potter. Ghosts are transparent.',
 "Professor McGonagall: Why is it when something bad happens, it's always you three? Ron: Believe me, Professor, I've been asking myself the exact same thing for the past six years.",
 "So why in the name of Merlin's saggy left - Don't talk to your mother like that.",
 'The idea of a teenage Dumbledore was simply odd, like trying to imagine a stupid Hermione or a friendly Blast-Ended Skrewt.',
 "Death's got an Invisibility Cloak? Harry interrupted again. So he can sneak up on people, said Ron. Sometimes he gets bored of running at them, flapping his arms and shrieking.",
 'He can move faster than Severus Snape confronted with shampoo.',
 'Well, thank you for that assessment, Mr Weasley. Perhaps it would be more useful if I were to transfigure Mr Potter and yourself into a pocket watch. That way, one of you might be on time.',
 "Hermione: Stop moving, both of you. This is devil's snare! You have to relax. If you don't, it'll only kill you faster! Ron: Kill us faster? Oh, now I can relax!",
 "So light a fire! Harry choked. Yes... of course... but there's no wood! ...  HAVE YOU GONE MAD! Ron bellowed. ARE YOU A WITCH OR NOT!",
 "Can you believe our luck? said Ron miserably, bending down to pick up Scabbers. Of all the trees we could've hit, we had to get one that hits back.",
 'Just then Neville caused a slight diversion by turning into a large canary.',
 'I am a wizard, not a baboon brandishing a stick.',
 'It does not do to dwell on dreams and forget to live, remember that.',
 'It is our choices, Harry, that show what we truly are far more than our abilities.',
 'Happiness can be found, even in the darkest of times, if one only remembers to turn on the light.',
 'As much money and life as you could want! The two things most human beings would choose above all - the trouble is, humans do have a knack of choosing precisely those things that are worst for them.',
 "Besides, the world isn't split into good people and Death Eaters. We've all got both light and dark inside us. What matters is the part we choose to act on. That's who we really are.",
 'Remember, if the time should come when you have to make a choice between what is right and what is easy, remember what happened to a boy who was good, and kind, and brave, because he strayed across the path of Lord Voldemort. Remember Cedric Diggory.',
 "Wit beyond measure is man's greatest treasure.",
 "We've all got both light and dark inside us. What matters is the part we choose to act on. That's who we really are.",
 'Let us step into the night and pursue that flighty temptress, adventure.',
 "The thing about growing up with Fred and George, said Ginny thoughtfully, is that you sort of start thinking anything's possible if you've got enough nerve.",
 'It was, he thought, the difference between being dragged into the arena to face a battle to the death and walking into the arena with your head held high. Some people, perhaps, would say that there was little to choose between the two ways, but Dumbledore knew - and so do I, thought Harry, with a rush of fierce pride, and so did my parents - that there was all the difference in the world.',
 'It was important, Dumbledore said, to fight, and fight again, and keep fighting, for only then could evil be kept at bay, though never quite eradicated...',
 'Power was my weakness and my temptation. It is a curious thing, Harry, but perhaps those who are best suited to power are those who have never sought it. Those who, like you, have leadership thrust upon them, and take up the mantle because they must, and find to their own surprise that they wear it well.',
 'There are all kinds of courage, said Dumbledore, smiling. It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.',
 'Understanding is the first step to acceptance, and only with acceptance can there be recovery.',
 'It is the unknown we fear when we look upon death and darkness, nothing more.',
 'Fear of a name increases fear of the thing itself.',
 'What you fear most of all is -fear. Very wise...',
 'Numbing the pain for a while will make it worse when you finally feel it.',
 'According to Madam Pomfrey, thoughts could leave deeper scars than almost anything else.',
 'Of course it is happening inside your head, Harry, but why on earth should that mean it is not real?',
 'Dark times lie ahead of us and there will be a time when we must choose between what is easy and what is right.',
 "I am what I am an' I'm not ashamed. 'Never be ashamed,' my ol' dad used ter say, 'there's some who'll hold it against you, but they're not worth bothern' with.",
 "Don't let the Muggles get you down.",
 'We must try not to sink beneath our anguish, Harry, but battle on.',
 'Working hard is important. But there is something that matters even more, believing in yourself.',
 "'It matters not what someone is born, but what they grow to be.",
 "There are some things you can't share without ending up liking each other, and knocking out a twelve-foot mountain troll is one of them.",
 "Go on, have a pasty, said Harry, who had never had anything to share before or, indeed, anyone to share it with. It was a nice feeling, sitting there with Ron, eating their way through all Harry's pasties, cakes, and candies (the sandwiches lay forgotten).",
 'Books! And cleverness! There are more important things - friendship and bravery.',
 'There are all kinds of courage, said Dumbledore, smiling. It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.',
 "I'm not blamin' yeh ...  but I gotta tell yeh, I thought you two'd value yer friend more'n broomsticks or rats. Tha's all.",
 "If you want to kill Harry, you'll have to kill us, too!",
 'Differences of habit and language are nothing at all if our aims are identical and our hearts are open.',
 "No, Harry, you listen, said Hermione. We're coming with you. That was decided months ago - years, really.",
 "Nobody's ever asked me to a party before, as a friend. Is that why you dyed your eyebrow, for the party? Should I do mine too?",
 'Luna had decorated her bedroom ceiling with five beautifully painted faces: Harry, Ron, Hermione, Ginny, and Neville. They were not moving as the portraits at Hogwarts moved, but there was a certain magic about them all the same: Harry thought they breathed. What appeared to be fine golden chains wove around the pictures, linking them together, but after examining them for a minute or so, Harry realized that the chains were actually one word, repeated a thousand times in golden ink: friends... friends ...  friends ...',
 "You think I'm a fool?demanded Harry. No, I think you're like James, said Lupin, who would have regarded it as the height of dishonor to mistrust his friends.",
 'It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.',
 'I believe your friends Misters Fred and George Weasley were responsible for trying to send you a toilet seat. No doubt they thought it would amuse you.',
 'We are only as strong as we are united, as weak as we are divided.',
 "We're with you whatever happens.",
 'The wand chooses the wizard. That much has always been clear to those of us who have studied wandlore.',
 'Curious indeed how these things happen. The wand chooses the wizard, remember...  I think we must expect great things from you, Mr Potter...  After all, He-Who-Must-Not-Be-Named did great things - terrible, yes, but great.',
 'There will be no foolish wand-waving or silly incantations in this class.',
 'Lockhart cuffed Harry merrily on the shoulder. Just do what I did, Harry! What, drop my wand?',
 'There was a lot more to magic, as Harry quickly found out, than waving your wand and saying a few funny words.',
 'But the idea of the Dark Lord in possession of the Deathstick is, I must admit, formidable.',
 "You talk about wands like they've got feelings, said Harry, like they can think for themselves.",
 "There was a moment, in the graveyard, where Voldemort's wand and mine sort of...  connected.",
 'And what if I wave my wand and nothing happens? Throw it away and punch him on the nose, Ron suggested.',
 "That wand's more trouble than it's worth. And quite honestly, I've had enough trouble for a life time.",
 'To the well-organized mind, death is but the next great adventure: filled with fun, majesty, and a bit of mischief.',
 "You think the dead we loved truly ever leave us? You think that we don't recall them more clearly in times of great trouble?",
 "You don't understand! whined Pettigrew. He would have killed me, Sirius! THEN YOU SHOULD HAVE DIED! roared Black. DIED RATHER THAN BETRAY YOUR FRIENDS, AS WE WOULD HAVE DONE FOR YOU!",
 'It was not, after all, so easy to die.',
 'The true master does not run away from Death. He accepts that he must die and knows that there are far, far worse things in the living world than dying.',
 'Do not pity the dead, Harry. Pity the living, and, above all those who live without love.',
 'But know this; the ones that love us never really leave us.',
 'It is the unknown we fear when we look upon death and darkness, nothing more.',
 'We are only as strong as we are united, as weak as we are divided.',
 'Power was my weakness and my temptation. It is a curious thing, Harry, but perhaps those who are best suited to power are those who have never sought it. Those who, like you, have leadership thrust upon them, and take up the mantle because they must, and find to their own surprise that they wear it well.',
 'There is no good and evil, there is only power, and those too weak to seek it...',
 "We've all got both light and dark inside us. What matters is the part we choose to act on. That's who we really are.",
 'We must try not to sink beneath our anguish, Harry, but battle on.',
 'It matters not what someone is born, but what they grow to be.',
 "I'm going to keep going until I succeed - or die. Don't think I don't know how this might end. I've known it for years.",
 "He couldn't know that at this very moment, people meeting in secret all over the country were holding up their glasses and saying in hushed voices: 'To Harry Potter - the boy who lived!",
 "Your mother died to save you. If there is one thing Voldemort cannot understand, it is love. He didn't realize that love as powerful as your mother's for you leaves its own mark.",
 "Just because it's taken you three years to notice, Ron, doesn't mean no one else has spotted I'm a girl!",
 'And that, boys, is why you should never go for looks alone.',
 'You should write a book, Ron told Hermione as he cut up his potatoes, translating mad things girls do so boys can understand them.',
 "Ginny, listen... I can't be involved with you anymore. We've got to stop seeing each other. We can't be together. It's for some stupid noble reason isn't it? It's been like... like something out of someone else's life these last few weeks with you. But I can't... we can't... I've got to do things alone now. Voldemort uses people his enemies are close to. He's already used you as bait once, and that was just because you were my best friend's sister. Think how much danger you'll be in if we keep this up. He'll know, he'll find out. He'll try and get me through you. What if I don't care? I care. How do you think I'd feel if this was your funeral... and it was my fault...",
 'When you have seen as much of life as I have, you will not underestimate the power of obsessive love.',
 "What do I care how 'e looks? I am good-looking enough for both of us, I theenk! All these scars show is zat my husband is brave!",
 'But this is touching, Severus, said Dumbledore seriously. Have you grown to care for the boy, after all? For him? shouted Snape. Expecto Patronum! From the tip of his wand burst the silver doe. She landed on the office floor, bounded once across the office, and soared out of the window. Dumbledore watched her fly away, and as her silvery glow faded he turned back to Snape, and his eyes were full of tears. After all this time? Always, said Snape.',
 'Do not pity the dead, Harry. Pity the living, and, above all those who live without love.',
 'And without thinking, without planning it, without worrying about the fact that fifty people were watching, Harry kissed her.',
 'You are protected, in short, by your ability to love!',
 'What was there to be gained by fighting the most evil wizard who has ever existed? Only innocent lives, Peter.',
 "When a wizard goes over ter the Dark Side there's nothin' and no one matters to 'em anymore...",
 "If you want to know what a man's like, take a good look at how he treats his inferiors, not his equals.",
 'There is no good and evil, there is only power, and those too weak to seek it...',
 'Remember, if the time should come when you have to make a choice between what is right and what is easy, remember what happened to a boy who was good, and kind, and brave, because he strayed across the path of Lord Voldemort. Remember Cedric Diggory.',
 'It is my belief...  that the truth is generally preferable to lies.',
 'Killing is not so easy as the innocent believe.',
 'Voldemort himself created his worst enemy, just as tyrants everywhere do! Have you any idea how much tyrants fear the people they oppress? All of them realize that, one day, amongst their many victims, there is sure to be one who rises against them and strikes back!',
 'Killing rips the soul apart.',
 "Thank you so much Dobby for rescuing me from that cellar. It's so unfair that you had to die when you were so good and brave. I'll always remember what you did for us. I hope you're happy now.",
 'It is important to fight and fight again, and keep fighting, for only then can evil be kept at bay though never quite eradicated.',
 "I don't go looking for trouble. Trouble usually finds me.",
 'Harry Potter was a highly unusual boy in many ways.',
 "The Sorting Hat: Hmmm, said a small voice in his ear. Difficult. Very difficult. Plenty of courage, I see. Not a bad mind either. There's talent, oh my goodness yes - and a nice thirst to prove yourself, now that's interesting...  So where shall I put you?",
 "Your aunt and uncle will be proud, though, won't they? said Hermione as they got off the train and joined the crowd thronging toward the enchanted barrier. When they hear what you did this year? Proud? said Harry. Are you crazy? All those times I could've died, and I didn't manage it? They'll be furious...",
 "They don't know we're not allowed to use magic at home. I'm going to have a lot of fun with Dudley this summer...",
 "To the Dursleys: He was my mum and dad's best friend. He's a convicted murderer, but he's broken out of wizard prison and he's on the run. He likes to keep in touch with me though...  keep up with news...  check if I'm happy...",
 "I'm not going to be murdered,' Harry said out loud. 'That's the spirit, dear, said his mirror sleepily.",
 "That's what they should teach us here how girls' brains work ...  it'd be more useful than Divination, anyway...",
 'It was, he thought, the difference between being dragged into the arena to face a battle to the death and walking into the arena with your head held high. Some people, perhaps, would say that there was little to choose between the two ways, but Dumbledore knew - and so do I, thought Harry, with a rush of fierce pride, and so did my parents - that there was all the difference in the world.',
 "Dumbledore's man through and through, aren't you Potter? Yeah I am, said Harry. Glad we straightened that out.",
 "He accused me of being Dumbledore's man through and through. How very rude of him. I told him I was.",
 'He will only be gone from the school when none here are loyal to him.',
 '[Harry thinks] how they had talked about fighting a losing battle, and that it was important to fight, and to fight again, and to keep fighting, to keep evil at bay, though never quite eradicated.',
 'Finally, the truth. Lying with his face pressed into the dusty carpet of the office where he had once thought he was learning the secrets of victory, Harry understood at last that he was not supposed to survive.',
 "But if it matters to you, you'll be able to choose Gryffindor over Slytherin. The Sorting Hat takes your choice into account. Really? It did for me, said Harry. He had never told any of his children that before, and he saw the wonder in Albus's face when he said it.",
 "So it all comes down to this, doesn't it? Does the wand in your hand know its last master was Disarmed? Because if it does...  I am the true master of the Elder Wand.",
 "Give it here, Malfoy, or I'll knock you off your broom!",
 "Not to be rude or anything, but this isn't really a great time for me to have a House Elf in my bedroom.",
 'I solemnly swear that I am up to no good.',
 "I didn't put my name in that cup, I don't want eternal glory.",
 "Facing this stuff in real life is not like school. In school if you make a mistake you can just try again tomorrow, but out there when you're a second away from being murdered or watching a friend die right before your eyes, you don't know what that's like.",
 'Working hard is important. But there is something that matters even more, believing in yourself.',
 'The prophecy said: neither one can live for the other one survives. It means one of us is gonna have to kill the other in the end.',
 'Every great wizard in history has started out as nothing more than what we are now, students. If they can do it, why not us?',
 "Even though we got a fight ahead of us, we've got one thing that Voldemort doesn't have. Something worth fighting for.",
 'Albus Severus Potter, you were named after two headmasters of Hogwarts. One of them was a Slytherin and he was the bravest man I ever knew.',
 'Mischief managed.',
 'One can never have enough socks.',
 'It does not do to dwell on dreams and forget to live, remember that.',
 "The truth.' Dumbledore sighed. 'It is a beautiful and terrible thing, and should therefore be treated with great caution.",
 'It matters not what someone is born, but what they grow to be.',
 'It is our choices, Harry, that show what we truly are, far more than our abilities.',
 'There are all kinds of courage, said Dumbledore, smiling. It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.',
 'Welcome to a new year at Hogwarts! Before we begin our banquet, I would like to say a few words. And here they are: Nitwit! Blubber! Oddment! Tweak!',
 'Scars can come in useful. I have one myself above my left knee which is a perfect map of the London Underground.',
 'Happiness can be found, even in the darkest of times, if one only remembers to turn on the light.',
 'The consequences of our actions are always so complicated, so diverse, that predicting the future is a very difficult business indeed.',
 'The Prophet is bound to report the truth occasionally, said Dumbledore, if only accidentally.',
 'Power was my weakness and my temptation. It is a curious thing, Harry, but perhaps those who are best suited to power are those who have never sought it. Those who, like you, have leadership thrust upon them, and take up the mantle because they must, and find to their own surprise that they wear it well.',
 'Do not pity the dead, Harry. Pity the living, and, above all those who live without love.',
 'Of course it is happening inside your head, Harry, but why on earth should that mean that it is not real?',
 'Words are, in my not-so-humble opinion, our most inexhaustible source of magic. Capable of both inflicting injury, and remedying it.',
 'People find it far easier to forgive others for being wrong than being right.',
 'To the well organised mind, death is but the next great adventure.',
 'Killing is not so easy as the innocent believe.',
 "You think the dead we loved truly ever leave us? You think we don't recall them more clearly in times of great trouble?",
 'It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.',
 'We are only as strong as we are united, as weak as we are divided.',
 'Alas! Earwax!',
 'Where your treasure is, there your heart will be also.',
 'Differences of habit and language are nothing at all if our aims are identical and our hearts are open.',
 'We must all face the choice between what is right, and what is easy.',
 'For in dreams we enter a world that is entirely our own. Let them swim in the deepest ocean or glide over the highest cloud.',
 'The best of us sometimes eat our words.',
 'Youth can not know how age thinks and feels, but old men are guilty if they forget what it is to be young.',
 'Numbing the pain for a while will make it worse when you finally feel it.',
 'While we may come from different places and speak in different tongues, our hearts beat as one.',
 'It is the unknown we fear when we look upon death and darkness. Nothing more.',
 'The truth. It is a beautiful and terrible thing, and should therefore be treated with caution.',
 'It is a curious thing, Harry, but perhaps those who are best suited to power are those who have never sought it.',
 'Ah, music, he said, wiping his eyes. A magic beyond all we do here!',
 'It was important, Dumbledore said, to fight, and fight again, and keep fighting, for only then could evil be kept at bay, though never quite eradicated . . .',
 'This pain is part of being human. . . the fact that you can feel pain like this is your greatest strength.',
 'As much money and life as you could want! The two things most human beings would choose above all - the trouble is, humans do have a knack of choosing precisely those things that are worst for them.',
 'You will find that I will only truly have left this school when none here are loyal to me.',
 "I hope you're pleased with yourselves. We could all have been killed - or worse, expelled.",
 "It's Wing-gar-dium Levi-o-sa, make the gar nice and long.",
 "But why's she got to go to the library? Because that's what Hermione does, said Ron, shrugging. When in doubt, go to the library.",
 "Just because it's taken you three years to notice, Ron, doesn't mean no one else has spotted I'm a girl!",
 'Time will not slow down when something unpleasant lies ahead.',
 "Are you planning to follow a career in Magical Law, Miss Granger? asked Scrimgeour. No, I'm not, retorted Hermione. I'm hoping to do some good in the world!",
 "Just because you've got the emotional range of a teaspoon doesn't mean we all have.",
 "Twitchy little ferret, aren't you, Malfoy?",
 "Neville, I'm really, really sorry about this. She raised her wand. Petrificus Totalus!",
 'Books! And cleverness! There are more important things - friendship and bravery.',
 "I mean, it's sort of exciting isn't it? Breaking the rules.",
 'Fear of a name only increases fear of the thing itself.',
 "I mean, you could claim that anything's real if the only basis for believing in it is that nobody's proved it doesn't exist!",
 "Don't you tell me what to do, Harry Potter!",
 "Actually I'm highly logical which allows me to look past extraneous detail and perceive clearly that which others overlook.",
 'Mudblood and proud of it.',
 "We will fight! We'll have to, to reach the snake! But let's not lose sight now of what we're supposed to be d-doing! We're the only ones who can end it!",
 "Ooh, you look much tastier than Crabbe and Goyle, Harry, said Hermione, before catching sight of Ron's raised eyebrows, blushing slightly and saying Oh you know what I mean - Goyle's Potion looked like bogies.",
 'No, she said, her voice quivering with anger, but I will write to your mother.',
 "Did you see me disarm Hermione, Harry? Only once said Hermione stung. I got you loads more then you got me- I did not only get you once, I got you at least three times- Well if you're counting the one where you tripped over your own feet and knocked the wand out of my hand-",
 'Three turns should do it.',
 "Honestly, am I the only person who's ever bothered to read Hogwarts, A History?",
 "The truth is that you don't think a girl would have been clever enough!",
 "Ah, yes,' he said softly, 'Harry Potter. Our new - celebrity.",
 "You are here to learn the subtle science and exact art of potion-making. As there is little foolish wand-waving here, many of you will hardly believe this is magic. I don't expect you will really understand the beauty of the softly simmering cauldron with its shimmering fumes, the delicate power of liquids that creep through human veins, bewitching the mind, ensnaring the senses . . . I can teach you how to bottle fame, brew glory, even stopper death - if you aren't as big a bunch of dunderheads as I usually have to teach.",
 "Well, you're expelling us aren't you? said Ron. Not today, Mr. Weasley. Snape looked as though Christmas had been canceled.",
 'Crabbe, loosen your hold a little. If Longbottom suffocates, it means a tedious amount of paperwork and I do have to mention it on your reference if you ever apply for a job.',
 "You dare use my own spells against me, Potter? It was I who invented them - I, the Half-Blood Prince! And you'd turn them on me like your filthy father, would you? I don't think so... No!",
 'Would you like me to [kill you] now? asked Snape, his voice heavy with irony. Or would you like a few moments to compose an epitaph?',
 'Hide them all, then. Keep her - them - safe. Please. And what will you give me in return, Severus? In - in return? Anything.',
 'Then you will find yourself easy prey for the Dark Lord! Fools who wear their hearts proudly on their sleeves, who cannot control their emotions, who wallow in sad memories and allow themselves to be provoked this easily - weak people, in other words - they stand no chance against his powers! He will penetrate your mind with absurd ease, Potter!',
 'Yes, it is easy to see that nearly six years of magical education have not been wasted on you, Potter. Ghosts are transparent.',
 'The Dark Arts are many, varied, ever-changing, and eternal. Fighting them is like fighting a many-headed monster, which, each time a neck is severed, sprouts a head even fiercer and cleverer than before. You are fighting that which is unfixed, mutating, indestructible.',
 'Would you like me to do it now? asked Snape, his voice heavy with irony. Or would you like a few moments to compose an epitaph?',
 'Look...  at...  me...',
 'Avada Kedavra!',
 'It is finished.',
 'And what if I wave my wand and nothing happens? Throw it away and punch him on the nose, Ron suggested.',
 "If you want to kill Harry, you'll have to kill us, too!",
 'I hate being poor.',
 "Whatever house I'm in, I hope she's not in it, said Ron. [Referring to Hermione]",
 'You should write a book, Ron told Hermione as he cut up his potatoes, translating mad things girls do so boys can understand them.',
 "Why are they all staring? demanded Albus as he and Rose craned around to look at the other students. Don't let it worry you, said Ron. It's me. I'm extremely famous.",
 'I want to fix that in my memory for ever. Draco Malfoy, the amazing bouncing ferret...',
 "I forgot we'll be hunting down Voldemort in a mobile library.",
 'A cat? Is that what they told you? It looks more like a pig with hair if you ask me.',
 "I'll fix it up with Mum and Dad, then I'll call you. I know how to use a fellytone now.",
 "Yeah, well, Percy wouldn't want to work for anyone with a sense of humour, would he? Percy wouldn't recognize a joke if it danced naked in front of him wearing Dobby's tea cozy.",
 'Can I have a look at Uranus too, Lavender?',
 "I don't know how to break this to you... but I think they might have noticed we broke into Gringotts.",
 'Neville will play Quidditch for England before Hagrid lets Dumbledore down.',
 "Can you believe our luck? said Ron miserably, bending down to pick up Scabbers. Of all the trees we could've hit, we had to get one that hits back.",
 "Don't let the Muggles get you down!",
 'Accio Brain!',
 "I'll make Goyle do lines, it'll kill him, he hates writing, said Ron happily. He lowered his voice to Goyle's low grunt and, screwing up his face in a look of pained concentration, mimed writing in midair. I...  must...  not...  look...  like...  a...  baboon's...  backside.",
 "And that's the second time we've saved your life tonight, you two-faced bastard!",
 'No, said Hermione shortly. Have either of you seen my copy of Numerology and Gramatica? Oh, yeah, I borrowed it for a bit of bedtime reading, said Ron, but very quietly.',
 "So that's little Scorpious. Make sure you beat him in every test, Rosie. Thank god you've inherited your mother's brains.",
 "Don't worry, you're just as sane as I am.",
 "I think they think I'm a bit odd, you know. Some people call me 'Loony' Lovegood, actually.",
 "Mistletoe, said Luna dreamily, pointing at a large clump of white berries placed almost over Harry's head. He jumped out from under it. Good thinking, said Luna seriously. It's often infested with nargles.",
 'You can laugh! But people used to believe that there were no such things as the Blibbering Humdinger or the Crumple-Horned Snorkack.',
 "I don't think you should be an Auror, Harry, said Luna unexpectedly. Everybody looked at her. The Aurors are part of the Rotfang Conspiracy, I thought everyone knew that. They're working to bring down the Ministry of Magic from within using a mixture of dark magic and gum disease.",
 'I liked the DA too. It was like having friends.',
 'Luna had decorated her bedroom ceiling with five beautifully painted faces: Harry, Ron, Hermione, Ginny, and Neville. They were not moving as the portraits at Hogwarts moved, but there was a certain magic about them all the same: Harry thought they breathed. What appeared to be fine golden chains wove around the pictures, linking them together, but after examining them for a minute or so, Harry realized that the chains were actually one word, repeated a thousand times in golden ink: friends...  friends . . . friends...',
 "I've never stunned anyone except in our D.A. lessons, said Luna, sounding mildly interested. That was noisier than I thought it would be.",
 'Which came first, the phoenix or the flame? ... I think the answer is that a circle has no beginning.',
 "A Wrackspurt...  They're invisible. They float in through your ears and make your brain go fuzzy, she said. I thought I felt one zooming around in here.",
 'I suspect Nargles are behind it.',
 "Hello, Harry! Oh, I've interrupted a deep thought, haven't I? I can see it growing smaller in your eyes.",
 'Oooh, look, a Blibbering Humdinger!',
 "I've never been to this part of the castle. Well, not awake. I sleepwalk, you see. That's why I wear shoes to bed.",
 "Wit beyond measure is man's greatest treasure.",
 'I want to commit the murder I was imprisoned for.',
 "You don't understand! whined Pettigrew. He would have killed me, Sirius! THEN YOU SHOULD HAVE DIED! roared Black. DIED RATHER THAN BETRAY YOUR FRIENDS, AS WE WOULD HAVE DONE FOR YOU!",
 "This is how it is - this is why you're not in the Order - you don't understand - there are things worth dying for!",
 "We've all got both light and dark inside us. What matters is the part we choose to act on. That's who we really are.",
 "He was my mum and dad's best friend. He's a convicted murderer, but he's broken out of wizard prison and he's on the run. He likes to keep in touch with me, though... keep up with my news... check if I'm happy...",
 "Marauder's Map to Snape: Mr. Padfoot would like to register his astonishment that an idiot like that ever became a professor.",
 "He might have crawled up into the airing cupboard and died, but I mustn't get my hopes up.",
 "If you want to know what a man's like, take a good look at how he treats his inferiors, not his equals.",
 'You think the dead we loved ever truly leave us?',
 'Well, [bad] times like that bring out the best in some people and the worst in others.',
 'The ones who love us never really leave us, you can always find them in here.',
 "The world isn't split into good people and Death Eaters.",
 'Dumbledore: Sirius was a brave, clever, and energetic man, and such men are not usually content to sit at home in hiding while they believe others to be in danger.',
 "We will see each other again, he said. You are - truly your father's son, Harry...",
 "What's life without a little risk?",
 "Longbottom, if brains were gold you'd be poorer than Weasley, and that's saying something.",
 'Who blacked your eye, Granger? I want to send them flowers.',
 "You don't know what I'm capable of, you don't know what I've done!",
 "Well, no one really knows until they get there, do they, but I know I'll be in Slytherin, all our family have been - imagine being in Hufflepuff, I think I'd leave, wouldn't you?",
 "I do feel so sorry, said Draco Malfoy, one Potions class, for all those people who have to stay at Hogwarts for Christmas because they're not wanted at home.",
 'Training for the ballet, Potter?',
 'I thought you were going to buy me a present.',
 "Famous Harry Potter, said Malfoy. Can't even go to a bookshop without making the front page.",
 "I haven't got any options! I've got to do it! He'll kill me! He'll kill my whole family!",
 "Honestly, if you were any slower, you'd be going backward.",
 "You'd better hurry up, they'll be waiting for 'the Chosen Captain' - 'The Boy Who Scored'- whatever they call you these days.",
 "You'll soon find out some wizarding families are much better than others, Potter. You don't want to go making friends with the wrong sort. I can help you there.",
 "Enemies of the Heir, beware! You'll be next, Mudbloods!",
 "When the Dark Lord takes over, is he going to care how many O.W.L.s or N.E.W.T.s anyone's got? Of course he isn't...  It'll be all about the kind of service he received, the level of devotion he was shown.",
 "You're a wizard, Harry.",
 "No good sittin' worryin' abou' it, he said. What's comin' will come, an' we'll meet it when it does.",
 'I AM NOT PAYING FOR SOME CRACKPOT OLD FOOL TO TEACH HIM MAGIC TRICKS! yelled Uncle Vernon. Hagrid seized his pink umbrella and whirled it over his head NEVER - he thundered - INSULT -ALBUS -DUMBLEDORE - IN - FRONT - OF - ME!',
 'Ah, shut up, Dursley, yeh great prune.',
 "Never, said Hagrid irritably, try an' get a straight answer out of a centaur. Ruddy stargazers. Not interested in anythin' closer'n the moon.",
 "I've decided to call him Norbert, said Hagrid, looking at the dragon with misty eyes. He really knows me now, watch. Norbert! Norbert! Where's Mummy?",
 "Tiny little bloke, my dad was. By the time I was six I could lift him up an' put him on top o' the dresser if he annoyed me. Used ter make him laugh...",
 "Well, yeh might've bent a few rules, Harry, bu' yeh're all righ' really, aren' you?",
 "Tha's my boy...  you show 'em, Harry, you show 'em. Beat 'em all.",
 "You all righ'? he said gruffly. Yeah, said Harry. No, yeh're not, said Hagrid. Course yeh're not. But yeh will be.",
 "Great man, Dumbledore. 'S long as we've got him, I'm not too worried.",
 "Yeh don' have ter be ashamed of what yeh are.",
 "Anything's possible if you've got enough nerve.",
 "You'd think people had better things to gossip about, said Ginny as she sat on the common room floor, leaning against Harry's legs and reading the Daily Prophet. Three Dementor attacks in a week, and all Romilda Vane does is ask me if it's true you've got a Hippogriff tattooed across your chest. Ron and Hermione both roared with laughter. Harry ignored them. What did you tell her? I told her it's a Hungarian Horntail, said Ginny, turning a page of the newspaper idly. Much more macho. Thanks, said Harry, grinning. And what did you tell her Ron's got? A Pygmy Puff, but I didn't say where.",
 "But you've been too busy saving the Wizarding World. Well...  I can't say I'm surprised. I knew this would happen in the end. I knew you wouldn't be happy unless you were hunting Voldemort. Maybe that's why I like you so much.",
 "Leave him alone, he didn't want all that! said Ginny. It was the first time she had spoken in front of Harry.",
 "I'm going to be expelled! I've looked forward to coming to Hogwarts ever since B-Bill came and n-now I'll have to leave and - w-what'll Mum and Dad say?",
 "Yeah, the D.A.'s good. Only let's make it stand for Dumbledore's Army because that's the Ministry's worst fear, isn't it?",
 "I just wish I'd asked you sooner. We could've had ages...  months...  years maybe...",
 "It's for some stupid, noble reason isn't it?",
 "Well, we're not sure, but we think he knocked himself out with his own bat.",
 'Excuse me, but I care what happens to Sirius as much as you do!',
 "But Bill's not that down-to-earth. He's a Curse-Breaker, isn't he, he likes a bit of adventure, a bit of glamour...  I expect that's why he's gone for Phlegm.",
 'I never really gave up on you. Not really. I always hoped...  Hermione told me to get on with life, maybe go out with some other people, relax a bit around you, because I never used to be able to talk if you were in the room, remember? And she thought you might take a bit more notice if I was a bit more - myself.',
 "There's the silver lining I'm looking for.",
 'There is no good and evil, there is only power, and those too weak to seek it...',
 'I can make things move without touching them. I can make animals do what I want without training them. I can make bad things happen to people who are mean to me. I can make them hurt, if I want...',
 'Voldemort, said Riddle softly, is my past, present, and future...',
 "Surely you didn't think I was going to keep my filthy Muggle father's name? No. I fashioned myself a new name, a name I knew wizards everywhere would one day fear to speak, when I became the greatest sorcerer in the world!",
 'Come out, Harry...  come out and play, then...  it will be quick...  it might even be painless...  I would not know...  I have never died...',
 'Kill the spare.',
 'I have been careless, and so have been thwarted by luck and chance, those wreckers of all but the best laid plans.',
 'Do not lie to Lord Voldemort, for he knows... he always knows...',
 'Greatness inspires envy, envy engenders spite, spite spawns lies.',
 'Do not lie to me! hissed the second voice. I can always tell, Wormtail!',
 "Harry! I'd almost forgotten you were here, standing on the bones of my father. I'd introduce you, but rumor has it you're almost as famous as me these days.",
 'The Boy-Who-Lived. How lies have fed your legend, Harry! Do you want to know what really happened thirteen years ago? Shall I divulge how I truly lost my powers? It was love. You see, when dear sweet Lily Potter gave her life for her only son, it provided him with the ultimate protection, I could not touch him. It was old magic, something I should have foreseen. But no matter, no matter, things have changed. I CAN TOUCH YOU...  NOW!',
 "I'm going to kill you, Harry Potter. I'm going to destroy you. After tonight, no one will ever again question my power. After tonight if they speak of you, they'll only speak of how you begged for death. And how I being a merciful Lord...  obliged.",
 "Don't you turn your back on me, Harry Potter! I want you to look at me when I kill you! I want to see the light leave your eyes!",
 'Avada Kedavra!',
 "How touching...  it hissed. I always value bravery ...  Yes boy, your parents were brave...  I killed your father first, and he put up a courageous fight ...  but your mother needn't have died ...  she was trying to protect you ...  Now give me the stone unless you want her to have died in vain.",
 "Haven't I already told you, said Riddle quietly, that killing Mudbloods doesn't matter to me any more? For many months now, my new target has been - you.",
 'And now you face me, like a man ...  straight-backed and proud, the way your father died...  And now - we duel.',
 'Bad Dobby! Bad Dobby!',
 "Socks are Dobby's favorite, favorite clothes, sir! I has seven now, sir...  But sir...  they has made a mistake in the shop, Harry Potter, they is giving you two the same!",
 'Dobby has heard of your greatness, sir, but of your goodness, Dobby never knew...',
 'Oh you is a bad elf, Dobby!',
 'Dobby will have to punish himself most grievously for coming to see you, sir. Dobby will have to shut his ears in the oven door for this.',
 'Dobby has never been asked to sit down by a wizard - like an equal.',
 'Harry Potter must not go back to Hogwarts.',
 'Dobby is used to death threats, sir. Dobby gets them five times a day at home.',
 "Harry Potter mustn't be angry with Dobby. Dobby did it for the best.",
 'Professor Dumbledore said we is free to - to...  call him a - a barmy old codger if we likes, sir!',
 'And if Dobby does it wrong, Dobby will throw himself off the topmost tower, Harry Potter!',
 'Dobby likes Professor Dumbledore very much, sir, and is proud to keep his secrets and our silence for him.',
 'Dobby is a free house-elf and he can obey anyone he likes and Dobby will do whatever Harry Potter wants him to do!',
 "Kreacher will not insult Harry Potter in front of Dobby! No he won't, or Dobby will shut Kreacher's mouth for him!",
 'Bellatrix Lestrange: You stupid elf! You could have killed me! Dobby: Dobby never meant to kill! Dobby only meant to maim, or seriously injure!',
 'Dobby is free.',
 "I'm worth twelve of you, Malfoy.",
 "It's a Remembrall! he [Neville] explained. Gran knows I forget things - this tells you if there's something you've forgotten to do. Look, you hold it tight like this and if it turns red - oh...  His face fell, because the Remembrall had suddenly glowed scarlet, ...  you've forgotten something...",
 "Thank goodness you found me! I've been out here for hours. I couldn't remember the new password to get into bed.",
 "Don't leave me!' said Neville, scrambling to his feet. 'I don't want to stay here alone, the Bloody Baron's been past twice already.",
 "Right, Neville,' said Professor Lupin. 'first things first: what would you say is the thing that frightens you most in the world? ...  Professor Snape.",
 "We're all going to keep fighting, Harry. You know that?",
 "I'll join you when Hell freezes over, said Neville. Dumbledore's Army! he shouted.",
 "We're his army, said Neville. Dumbledore's Army. We were all in it together, we've been keeping it going while you three have been off on your own.",
 "Gran is on the run. She sent me a letter,' he clapped a hand to the breast pocket of his robes, 'telling me she was proud of me, that I'm my parents' son, and to keep it up.",
 "Gran, I've lost my toad again.",
 "Ask us no questions and we'll tell you no lies.",
 "Fred and George turned to each other and said together, Wow, we're identical! I dunno though, I think I'm still better looking, said Fred, examining his reflection in the kettle.",
 "Hey, look - Harry's got a Weasley sweater, too! Fred and George were wearing blue sweaters, one with a large yellow F on it, the other a G. Harry's is better than ours, though, said Fred, holding up Harry's sweater. She obviously makes more of an effort if you're not family.",
 'Time is Galleons, little brother.',
 'Honestly, woman, you call yourself our mother?',
 "Now, you two - this year, you behave yourselves. If I get one more owl telling me you've - you've blown up a toilet or - Blown up a toilet? We've never blown up a toilet. Great idea though, thanks, Mum.",
 "Where's the fun without a bit of risk?",
 "Time to sit down, Fred told Harry, Or we're going to get run over by the bride.",
 "We'll send you a Hogwarts toilet seat!",
 "You haven't got a letter on yours, George observed. I suppose she thinks you don't forget your name. But we're not stupid-we know we're called Gred and Forge.",
 'Everybody finished the song at different times. At last, only the Weasley twins were left singing along to a very slow funeral march.',
 "What do we want to be prefects for? said George, looking revolted at the very idea. It'd take all the fun out of life.",
 'Anyone can speak Troll. All you have to do is point and grunt.',
 "Harry's in a hurry. Yeah, he's off to the Chamber of Secrets for a cup of tea with his fanged servant, said George, chortling.",
 'Give her hell from us, Peeves.',
 'It does not do to dwell on dreams and forget to live, remember that.',
 "You're a wizard, Harry.",
 "There are all kinds of courage,' said Dumbledore, smiling. 'It takes a great deal of bravery to stand up to our enemies, but just as much to stand up to our friends.",
 'To the well-organized mind, death is but the next great adventure: filled with fun, majesty, and a bit of mischief.',
 'Mr. and Mrs. Dursley, of number four, Privet Drive, were proud to say that they were perfectly normal, thank you very much.',
 "You haven't got a letter on yours, George observed. I suppose she thinks you don't forget your name. But we're not stupid-we know we're called Gred and Forge.",
 "This boy will be famous, a legend. I wouldn't be surprised if today was known as Harry Potter day in future. There will be books written about Harry, every child in our world will know his name.",
 "Now, you two - this year, you behave yourselves. If I get one more owl telling me you've - you've blown up a toilet or - Blown up a toilet? We've never blown up a toilet. Great idea though, thanks, Mum.",
 'Nitwit! Blubber! Oddment! Tweak!',
 'Scars can come in useful. I have one myself above my left knee which is a perfect map of the London Underground.',
 'Curious indeed how these things happen. The wand chooses the wizard, remember...  I think we must expect great things from you, Mr Potter...  After all, He-Who-Must-Not-Be-Named did great things - terrible, yes, but great.',
 "Don't talk rubbish, said Uncle Vernon. There is no platform nine and three-quarters.",
 "Whatever house I'm in, I hope she's not in it, said Ron. [Referring to Hermione]",
 'Before we begin our banquet, I would like to say a few words. And here they are: Nitwit! Blubber! Oddment! Tweak! Thank you.',
 "Ah, yes,' he said softly, 'Harry Potter. Our new - celebrity.",
 'And what if I wave my wand and nothing happens? Throw it away and punch him on the nose, Ron suggested.',
 "I hope you're pleased with yourselves. We could all have been killed - or worse, expelled.",
 "It's Wing-gar-dium Levi-o-sa, make the 'gar' nice and long.",
 'What happened down in the dungeons between you and Professor Quirrell is a complete secret, so, naturally the whole school knows.',
 "There are some things you can't share without ending up liking each other, and knocking out a twelve-foot mountain troll is one of them.",
 'There was a lot more to magic, as Harry quickly found out, than waving your wand and saying a few funny words.',
 "Longbottom, if brains were gold you'd be poorer than Weasley, and that's saying something.",
 'Ah, music, he said, wiping his eyes. A magic beyond all we do here!',
 "I tell you, that dragon's the most horrible animal I've ever met, but the way Hagrid goes on about it, you'd think it was a fluffy little bunny rabbit. When it bit me he told me off for frightening it. And when I left, he was singing it a lullaby.",
 'Neville will play Quidditch for England before Hagrid lets Dumbledore down.',
 "So light a fire! Harry choked. Yes... of course... but there's no wood! ...  HAVE YOU GONE MAD! Ron bellowed. ARE YOU A WITCH OR NOT!",
 "Harry - you're a great wizard, you know. I'm not as good as you, said Harry, very embarrassed, as she let go of him. Me!' said Hermione. 'Books! And cleverness! There are more important things - friendship and bravery.",
 'Alas! Earwax!',
 'There is no good and evil, there is only power, and those too weak to seek it...',
 'Humans do have a knack for choosing precisely those things which are worst for them.',
 'Fear of a name increases fear of the thing itself.',
 'As much money and life as you could want! The two things most human beings would choose above all - the trouble is, humans do have a knack of choosing precisely those things that are worst for them.',
 'The truth. Dumbledore sighed. It is a beautiful and terrible thing, and should therefore be treated with great caution.',
 "Your mother died to save you. If there is one thing Voldemort cannot understand, it is love. He didn't realize that love as powerful as your mother's for you leaves its own mark.",
 "They don't know we're not allowed to use magic at home. I'm going to have a lot of fun with Dudley this summer...",
 'It is our choices, Harry, that show what we truly are, far more than our abilities.',
 "Oh well...  I'd just been thinking, if you had died, you'd have been welcome to share my toilet.",
 "Of all the trees we could've hit, we had to get one that hits back.",
 'Jiggery pokery!...  Hocus pocus-squiggly wiggly!',
 "Honestly, if you were any slower, you'd be going backward.",
 "YOU COULD DO WITH TAKING A LEAF OUT OF PERCY'S BOOK!",
 "Ginny! said Mr. Weasley, flabbergasted. Haven't I taught you anything? What have I always told you? Never trust anything that can think for itself if you can't see where it keeps its brain?",
 "Well, you're expelling us aren't you? said Ron. Not today, Mr. Weasley. Snape looked as though Christmas had been canceled.",
 'D-Dia-gon Alley.',
 "Your sons flew that car to Harry's house and back last night! ...  What have you got to say about that, eh? Did you really... Did it go all right? I - I mean... that - that was very wrong, boys - very wrong indeed...",
 "I'll be in my bedroom, making no noise and pretending I'm not there.",
 "You'd better hope Creevey doesn't meet Ginny, or they'll be starting a Harry Potter fan club.",
 "But why's she got to go to the library? Because that's what Hermione does, said Ron, shrugging. When in doubt, go to the library.",
 'You will find that I will only truly have left this school when none here are loyal to me.',
 "Your aunt and uncle will be proud, though, won't they? said Hermione as they got off the train and joined the crowd thronging toward the enchanted barrier. When they hear what you did this year? Proud? said Harry. Are you crazy? All those times I could've died, and I didn't manage it? They'll be furious...",
 "Lockhart'll sign anything if it stands still long enough.",
 "You nearly got Ron and me expelled, he said fiercely. You'd better get lost before my bones grow back, or I might strangle you.",
 "Haven't I already told you, said Riddle, that killing Mudbloods doesn't matter to me any more? For many months now, my new target has been you.",
 "Ron's old Shooting Star was often outstripped by passing butterflies.",
 "Hearing voices no one else can hear isn't a good sign, even in the wizarding world.",
 'I WILL NOT TOLERATE MENTION OF YOUR ABNORMALITY UNDER THIS ROOF!',
 'You will also find that help will always be given at Hogwarts to those who ask for it.',
 'It is our choices, Harry, that show what we truly are far more than our abilities.',
 'Dobby is free.',
 'Voldemort, said Riddle softly, is my past, present, and future...',
 'I solemnly swear that I am up to no good.',
 "He was my mum and dad's best friend. He's a convicted murderer, but he's broken out of wizard prison and he's on the run. He likes to keep in touch with me, though... keep up with my news... check if I'm happy...",
 "Where is Wood? said Harry, suddenly realizing he wasn't there. Still in the showers, said Fred. We think he's trying to drown himself.",
 "You think the dead we loved truly ever leave us? You think that we don't recall them more clearly in times of great trouble?",
 'We tried to shut Percy in a pyramid. But Mum spotted us.',
 "Don't let the muggles get you down.",
 'I want to commit the murder I was imprisoned for.',
 "I dreamed I was buying new shoes last night, said Ron. What d'ya think that's gonna mean? Probably that you're going to be eaten by a giant marshmallow or something, said Harry.",
 "You don't understand! whined Pettigrew. He would have killed me, Sirius! THEN YOU SHOULD HAVE DIED! roared Black. DIED RATHER THAN BETRAY YOUR FRIENDS, AS WE WOULD HAVE DONE FOR YOU!",
 'Happiness can be found, even in the darkest of times, if one only remembers to turn on the light.',
 'Are you insane? Of course I want to leave the Dursleys! Have you got a house? When can I move in?',
 "How're we getting to King's Cross tomorrow, Dad? asked Fred as they dug into a sumptuous pudding. The Ministry's providing a couple of cars, said Mr. Weasley. Everyone looked up at him. Why? said Percy curiously. It's because of you, Perce, said George seriously. And there'll be little flags on the hoods, with HB on them- -for Humongous Bighead, said Fred.",
 'Mischief Managed',
 "What you fear most of all is-fear. Very wise. I'm not going to be murdered, Harry said out loud. That's the spirit, dear, said his mirror sleepily.",
 'The consequences of our actions are always so complicated, so diverse, that predicting the future is a very difficult business indeed.',
 "Why, dear boy, we don't send wizards to Azkaban just for blowing up their aunts.",
 "If you made a better rat than a human, it's not much to boast about, Peter.",
 "When a wizard goes over ter the Dark Side there's nothin' and no one matters to 'em anymore.",
 "Besides, the world isn't split into good people and Death Eaters. We've all got both light and dark inside us. What matters is the part we choose to act on. That's who we really are.",
 'Harry Potter was a highly unusual boy in many ways.',
 "What do we want to be prefects for? said George, looking revolted at the very idea. It'd take all the fun out of life.",
 "I don't go looking for trouble. Trouble usually finds me.",
 "I'm not blamin' yeh...  but I gotta tell yeh, I thought you two'd value yer friend more'n broomsticks or rats. Tha's all.",
 'What was there to be gained by fighting the most evil wizard who has ever existed? Only innocent lives, Peter.',
 "If you want to kill Harry, you'll have to kill us, too!",
 "If you want to know what a man's like, take a good look at how he treats his inferiors, not his equals.",
 'It matters not what someone is born, but what they grow to be.',
 "Not nice, he said calmly. Not pleasant. And there's no counter-curse. There's no blocking it. Only one known person has ever survived it, and he's sitting in this room.",
 'Remember, if the time should come when you have to make a choice between what is right and what is easy, remember what happened to a boy who was good, and kind, and brave, because he strayed across the path of Lord Voldemort. Remember Cedric Diggory.',
 'Numbing the pain for a while will make it worse when you finally feel it.',
 'We are only as strong as we are united, as weak as we are divided.',
 "Percy wouldn't notice a joke if it danced naked in front of him wearing one of Dobby's hats.",
 "Don't talk to me. Why not? Because I want to fix that in my memory for ever. Draco Malfoy, the amazing bouncing ferret...",
 'It is my belief...  that the truth is generally preferable to lies.',
 'You need preparing. You need arming. But most of all, you need constant, never ceasing vigilance.',
 'Understanding is the first step to acceptance, and only with acceptance can there be recovery.',
 'Differences of habit and language are nothing at all if our aims are identical and our hearts are open.',
 "Well, I certainly don't, said Percy sanctimoniously. I shudder to think what the state of my in-tray would be if I was away from work for five days. Yeah, someone might slip dragon dung in it again, eh, Perce? said Fred. That was a sample of fertilizer from Norway! said Percy, going very red in the face. It was nothing personal! It was, Fred whispered to Harry as they got up from the table. We sent it.",
 'Wild! I can make that old bloke down there pick his nose again...  and again...  and again...',
 'Time will not slow down when something unpleasant lies ahead.',
 "Course Dumbledore trusts you. He's a trusting man, isn't he? Believes in second chances. But me, I say there are spots that don't come off, Snape. Spots that never come off, d'you know what I mean?",
 'What would come, would come...  and you would have to meet it, when it did.',
 'It is a strange thing, but when you are dreading something, and would give anything to slow down time, it has a disobliging habit of speeding up.',
 'Anyone can speak Troll. All you have to do is point and grunt.',
 'Just then Neville caused a slight diversion by turning into a large canary.',
 "I'm never wearing them, Ron was saying stubbornly. Never. Fine, snapped Mrs. Weasley. Go naked. And, Harry, make sure you get a picture of him. Goodness knows I could do with a laugh.",
 "Socks are Dobby's favorite, favorite clothes, sir! I has seven now, sir...  But sir...  they has made a mistake in the shop, Harry Potter, they is giving you two the same!",
 'Curiosity is not a sin...  But we should exercise caution with our curiosity...  yes, indeed.',
 'Constant vigilance!',
 'Come out, Harry...  come out and play, then...  it will be quick...  it might even be painless...  I would not know...  I have never died...',
 'Kill the spare.',
 'Do not lie to Lord Voldemort, for he knows... he always knows...',
 "Really, Hagrid, if you are holding out for universal popularity, I'm afraid you will be in this cabin for a very long time.",
 "Twitchy little ferret, aren't you, Malfoy?",
 'Can I have a look at Uranus too, Lavender?',
 "What's comin' will come, an' we'll meet it when it does.",
 "Well, I can certainly see why we're trying to keep them alive. Who wouldn't want pets that can burn, sting, and bite all at once?",
 "I am what I am, an' I'm not ashamed. 'Never be ashamed,' my ol' dad used ter say, 'there's some who'll hold it against you, but they're not worth botherin' with.",
 "There you go, Harry! You weren't being thick after all; you were just showing moral fiber!",
 "Wit beyond measure is man's greatest treasure.",
 "Just because you have the emotional range of a teaspoon doesn't mean we all have.",
 'Indifference and neglect often do much more damage than outright dislike.',
 'Is it true that you shouted at Professor Umbridge? Yes. You called her a liar? Yes. You told her He Who Must Not Be Named is back? Yes. Have a biscuit, Potter.',
 "You're a prefect? Oh Ronnie! That's everyone in the family! What are Fred and I? Next door neighbors?",
 'You care so much you feel as though you will bleed to death with the pain of it.',
 "You know, Minister, I disagree with Dumbledore on many counts...  but you cannot deny he's got style.",
 'Yeah, Quirrell was a great teacher. There was just that minor drawback of him having Lord Voldemort sticking out of the back of his head!',
 'Things we lose have a way of coming back to us in the end, if not always in the way we expect.',
 'Listening to the news! Again? Well, it changes every day, you see, said Harry.',
 'Youth can not know how age thinks and feels. But old men are guilty if they forget what it was to be young.',
 'Give her hell from us, Peeves.',
 'Accio Brain!',
 "But Dumbledore says he doesn't care what they do as long as they don't take him off the Chocolate Frog cards.",
 "From now on, I don't care if my tea leaves spell 'Die, Ron, Die,' I'm chucking them in the bin where they belong.",
 'I have absolutely no intention of being sent to Azkaban. I could break out, of course - but what a waste of time, and frankly, I can think of a whole host of things I would rather be doing.',
 "Don't put your wand there, boy! ...  Better wizards than you have lost buttocks, you know.",
 'You should write a book, Ron told Hermione as he cut up his potatoes, translating mad things girls do so boys can understand them.',
 'According to Madam Pomfrey, thoughts could leave deeper scars than almost anything else.',
 "Don't worry. You're just as sane as I am.",
 'The mind is not a book, to be opened at will and examined at leisure. Thoughts are not etched on the inside of skulls, to be perused by an invader. The mind is a complex and many-layered thing.',
 "We've all got both light and dark inside us. What matters is the part we choose to act on. That's who we really are.",
 "I'm sure I must have misunderstood you, Professor Dumbledore, so silly of me. But it sounded for a teensy moment as though you were suggesting that the Ministry of Magic had ordered an attack on this boy!",
 "Mistletoe, said Luna dreamily, pointing at a large clump of white berries placed almost over Harry's head. He jumped out from under it. Good thinking, said Luna seriously. It's often infested with nargles.",
 'By all means continue destroying my possessions. I daresay I have too many.',
 'You can laugh! But people used to believe there were no such things as the Blibbering Humdinger or the Crumple-Horned Snorkack!',
 "We can't choose our fate, but we can choose others. Be careful in knowing that.",
 "Ask us no questions and we'll tell you no lies.",
 'ARE YOU MAD, MAD-EYE?',
 "Do you remember me telling you we are practicing non-verbal spells, Potter? Yes, said Harry stiffly. Yes, sir. There's no need to call me sir Professor.",
 'It is the unknown we fear when we look upon death and darkness, nothing more.',
 'Let us step into the night and pursue that flighty temptress, adventure.',
 'Dumbledore says people find it far easier to forgive others for being wrong than being right.',
 "The thing about growing up with Fred and George, said Ginny thoughtfully, Is that you sort of start thinking anything's possible if you've got enough nerve.",
 'It was, he thought, the difference between being dragged into the arena to face a battle to the death and walking into the arena with your head held high. Some people, perhaps, would say that there was little to choose between the two ways, but Dumbledore knew - and so do I, thought Harry, with a rush of fierce pride, and so did my parents - that there was all the difference in the world.',
 "You'd think people had better things to gossip about, said Ginny as she sat on the common room floor, leaning against Harry's legs and reading the Daily Prophet. Three Dementor attacks in a week, and all Romilda Vane does is ask me if it's true you've got a Hippogriff tattooed across your chest. Ron and Hermione both roared with laughter. Harry ignored them. What did you tell her? I told her it's a Hungarian Horntail, said Ginny, turning a page of the newspaper idly. Much more macho. Thanks, said Harry, grinning. And what did you tell her Ron's got? A Pygmy Puff, but I didn't say where.",
 "An Unbreakable Vow? said Ron, looking stunned. Nah, he can't have...  Are you sure? Yes I'm sure, said Harry. Why, what does it mean? Well, you can't break an Unbreakable Vow...  I'd worked that much out for myself, funnily enough.",
 "You could say sorry, suggested Harry bluntly. What, and get attacked by another flock of canaries? muttered Ron. What did you have to imitate her for? She laughed at my mustache! So did I, it was the stupidest thing I've ever seen.",
 "Sometimes you remind me a lot of James. He called it my 'furry little problem' in company. Many people were under the impression that I owned a badly behaved rabbit.",
 "Dumbledore's man through and through, aren't you Potter? Yeah I am, said Harry. Glad we straightened that out.",
 "We'll be there, Harry, said Ron. What? At your Aunt and Uncle's house, said Ron, And then we'll go with you wherever you're going. No- said Harry quickly; he hadn't counted on this, he had meant them to understand that he was undertaking the most dangerous journey alone. You said it once before, said Hermione quickly, that there was time to turn back if we wanted to. We've had time, haven't we? We're with you whatever happens.",
 "Ginny, listen... I can't be involved with you anymore. We've got to stop seeing each other. We can't be together. It's for some stupid noble reason isn't it? It's been like... like something out of someone else's life these last few weeks with you. But I can't... we can't... I've got to do things alone now. Voldemort uses people his enemies are close to. He's already used you as bait once, and that was just because you were my best friend's sister. Think how much danger you'll be in if we keep this up. He'll know, he'll find out. He'll try and get me through you. What if I don't care? I care. How do you think I'd feel if this was your funeral... and it was my fault...",
 'When you have seen as much of life as I have, you will not underestimate the power of obsessive love.',
 'I make mistakes like the next man. In fact, being-forgive me-rather cleverer than most men, my mistakes tend to be correspondingly huger.',
 'Killing is not so easy as the innocent believe.',
 "Nobody's ever asked me to a party before, as a friend. Is that why you dyed your eyebrow, for the party? Should I do mine too?",
 'Once again, you show all the sensitivity of a blunt axe.',
 'Voldemort himself created his worst enemy, just as tyrants everywhere do! Have you any idea how much tyrants fear the people they oppress? All of them realize that, one day, amongst their many victims, there is sure to be one who rises against them and strikes back!',
 "What do I care how 'e looks? I am good-looking enough for both of us, I theenk! All these scars show is zat my husband is brave!",
 'Yes, it is easy to see that nearly six years of magical education have not been wasted on you, Potter. Ghosts are transparent.',
 'I am a wizard, not a baboon brandishing a stick.',
 'Age is foolish and forgetful when it underestimates youth.',
 'It was important, Dumbledore said, to fight, and fight again, and keep fighting, for only then could evil be kept at bay, though never quite eradicated...',
 'Greatness inspires envy, envy engenders spite, spite spawns lies.',
 'Killing rips the soul apart.',
 'The Prophet is bound to report the truth occasionally, said Dumbledore, if only accidentally.',
 'I am not worried, Harry, I am with you.',
 "Why are you worrying about YOU-KNOW-WHO, when you should be worrying about YOU-NO-POO? The constipation sensation that's gripping the nation!",
 "You don't know what I'm capable of, you don't know what I've done!",
 "I haven't got any options! I've got to do it! He'll kill me! He'll kill my whole family!",
 'Avada Kedavra!',
 'It is finished.',
 "You dare use my own spells against me, Potter? It was I who invented them - I, the Half-Blood Prince! And you'd turn them on me like your filthy father, would you? I don't think so... No!",
 "Professor McGonagall: Why is it when something bad happens, it's always you three? Ron: Believe me, Professor, I've been asking myself the exact same thing for the past six years.",
 'Hogwarts was the first and best home he had known. He and Voldemort and Snape, the abandoned boys, had all found home here.',
 'But this is touching, Severus, said Dumbledore seriously. Have you grown to care for the boy, after all? For him? shouted Snape. Expecto Patronum! From the tip of his wand burst the silver doe. She landed on the office floor, bounded once across the office, and soared out of the window. Dumbledore watched her fly away, and as her silvery glow faded he turned back to Snape, and his eyes were full of tears. After all this time? Always, said Snape.',
 "So that's little Scorpious. Make sure you beat him in every test, Rosie. Thank god you've inherited your mother's brains.",
 "What are you doing with all those books anyway? Ron asked. Just trying to decide which ones to take with us, said Hermione. When we're looking for the Horcruxes. Oh, of course, said Ron, clapping a hand to his forehead. I forgot we'll be hunting down Voldemort in a mobile library.",
 'Would it hurt to die?',
 'Luna had decorated her bedroom ceiling with five beautifully painted faces: Harry, Ron, Hermione, Ginny, and Neville. They were not moving as the portraits at Hogwarts moved, but there was a certain magic about them all the same: Harry thought they breathed. What appeared to be fine golden chains wove around the pictures, linking them together, but after examining them for a minute or so, Harry realized that the chains were actually one word, repeated a thousand times in golden ink: friends . . . friends . . . friends . . .',
 'I wish... I wish I were dead...  And what use would that be to anyone?',
 "Great, tell me when you've defeated Voldemort for me, will you?",
 "So why in the name of Merlin's saggy left - Don't talk to your mother like that.",
 "You think I'm a fool? demanded Harry. No, I think you're like James, said Lupin, who would have regarded it as the height of dishonor to mistrust his friends.",
 "I'm Draco Malfoy, I'm Draco, I'm on your side! Draco was on the upper landing, pleading with another masked Death Eater. Harry Stunned the Death Eater as they passed: Malfoy looked around, beaming, for his savior, and Ron punched him from under the cloak. Malfoy fell backward on top of the Death Eater, his mouth bleeding, utterly bemused. And that's the second time we've saved your life tonight, you two-faced bastard! Ron yelled.",
 'The idea of a teenage Dumbledore was simply odd, like trying to imagine a stupid Hermione or a friendly Blast-Ended Skrewt.',
 "Hello, Minister! bellowed Percy, sending a neat jinx straight at Thicknesse, who dropped his wand and clawed at the front of his robes, apparently in awful discomfort. Did I mention I'm resigning?",
 'It was not, after all, so easy to die.',
 "Are you planning to follow a career in Magical Law, Miss Granger? asked Scrimgeour. No, I'm not, retorted Hermione. I'm hoping to do some good in the world!",
 'Finally, the truth. Lying with his face pressed into the dusty carpet of the office where he had once thought he was learning the secrets of victory, Harry understood at last that he was not supposed to survive.',
 "We're all going to keep fighting, Harry. You know that?",
 'Would you like me to [kill you] now? asked Snape, his voice heavy with irony. Or would you like a few moments to compose an epitaph?',
 'Hide them all, then. Keep her - them - safe. Please. And what will you give me in return, Severus? In - in return? Anything.',
 "But if it matters to you, you'll be able to choose Gryffindor over Slytherin. The Sorting Hat takes your choice into account. Really? It did for me, said Harry. He had never told any of his children that before, and he saw the wonder in Albus's face when he said it.",
 'The ministry has fallen. Scrimgeour is dead. They are coming.',
 'Which came first, the phoenix or the flame? ... I think the answer is that a circle has no beginning. Well reasoned.',
 'I open at the close.',
 'I have been careless, and so have been thwarted by luck and chance, those wreckers of all but the best laid plans.',
 'Where your treasure is, there will your heart be also.',
 'The time has come for Slytherin House to decide upon its loyalties.',
 "Harry Potter. 'The Boy Who Lived.",
 'Power was my weakness and my temptation. It is a curious thing, Harry, but perhaps those who are best suited to power are those who have never sought it. Those who, like you, have leadership thrust upon them, and take up the mantle because they must, and find to their own surprise that they wear it well.',
 'The true master does not run away from Death. He accepts that he must die and knows that there are far, far worse things in the living world than dying.',
 'Of course it is happening inside your head, Harry, but why on earth should that mean that it is not real?',
 "So it all comes down to this, doesn't it? Does the wand in your hand know its last master was Disarmed? Because if it does...  I am the true master of the Elder Wand.",
 'The scar had not pained Harry for nineteen years. All was well.']


from textwrap import wrap 
import argparse 

_MAX_LINE_LENGTH = 30
_TOP_BOTTOM_PADDING = 3
_PADDING_LENGTH = 2
_TAB_LENGTH = "       "

def get_top(line_length):
    """Returns the top of the ascii thought""" 
    return _TAB_LENGTH + "".join(["-" for _ in range(line_length+_TOP_BOTTOM_PADDING)])

def get_bottom(line_length):
    """Returns the bottom of the ascii thought""" 
    return _TAB_LENGTH + "".join(["-" for _ in range(line_length+_TOP_BOTTOM_PADDING)])

def get_padding(message, max_line_length):
    end_pad_length = max([_PADDING_LENGTH, _PADDING_LENGTH + max_line_length - len(message)])
    init_pad_length = min([_PADDING_LENGTH, _PADDING_LENGTH + max_line_length - len(message)])
    padding = "".join([" " for _ in range(end_pad_length)])
    init_padding = "".join([" " for _ in range(init_pad_length)]) 
    return "{}{}{}".format(init_padding, message, padding)

def parse_message(message): 
    """Parse message into ascii art"""
    delimiters = {
		"first" : ["/", "\\"],
		"middle" : ["|", "|"],
		"only" : ["(", ")"],
		"last" : ["\\", "/"]
	};
    
    wrapped_lines = wrap(message, width=_MAX_LINE_LENGTH)
    max_line_length = max(len(line) for line in wrapped_lines)
    
    formatted_message = [get_top(max_line_length)]

    for index, line in enumerate(wrapped_lines): 
        message = ""
        if len(wrapped_lines) == 1: 
            delimiter = delimiters['only']
        elif index == len(wrapped_lines) - 1: 
            delimiter = delimiters['last']
        elif index == 0: 
            delimiter = delimiters['first']
        else: 
            delimiter = delimiters['middle']
        
        formatted_message.append("{}{} {} {}".format("     ", delimiter[0], get_padding(line, max_line_length), delimiter[1]))
            
        
    
    formatted_message += [get_bottom(max_line_length)]
    formatted_message_string = "\n".join(formatted_message)
    ascii_art = get_potter_ascii_art()
    return "{}{}".format(formatted_message_string, ascii_art)
    
def get_potter_ascii_art(): 
    """Returns a harry potter art as format string"""
    return r"""                            

            _            _.,----,        /
 __  _.-._ / '-.        -  ,._  \)      /
|  `-)_   '-.   \       / < _ )/" }    /
/__    '-.   \   '-, ___(c-(6)=(6)    /  
 , `'.    `._ '.  _,'   >\    "  )   /
 :;;,,'-._   '---' (  ( "/`. -='/
;:;;:;;,  '..__    ,`-.`)'- '--'
;';:;;;;;'-._ /'._|   Y/   _/' \
      '''"._ F    |  _/ _.'._   `\
             L    \   \/     '._  \
      .-,-,_ |     `.  `'---,  \_ _|
      //    'L    /  \,   ("--',=`)7
     | `._       : _,  \  /'`-._L,_'-._
     '--' '-.\__/ _L   .`'         './/
                 [ (  /
                  ) `{
                   \__)
"""

def generate_quote(): 
    import quote_list
    import random
    QUOTES = quote_list.QUOTES
    random_index = random.randrange(len(QUOTES))
    parsed_message = parse_message(QUOTES[random_index])
    print(parsed_message)

if __name__ == '__main__':
    generate_quote()



from setuptools import setup, find_packages

setup(
    name='pottersay',
    version='0.1.3',
    description='Generate a random Harry Potter quote in ASCII art.',
    url='http://github.com/defcon-007/pottersay',
    author='Ayush Goyal',
    author_email='ayushgoyal.iitkgp@gmail.com',
    license='MIT',
    packages=find_packages(),
    entry_points=dict(
        console_scripts=['pottersay=src.main:generate_quote']
    )
)